﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace INS88Sample
{
    public partial class Form1 : Form
    {
        private short DevId;
        private System.Windows.Forms.PictureBox[] StatDisp;
        private System.Windows.Forms.PictureBox[] DirCntl;
        private System.Windows.Forms.PictureBox[] EdgeDisp;
        private System.Windows.Forms.CheckBox[] OutBit;

        public Form1()
        {
            InitializeComponent();

            StatDisp = new System.Windows.Forms.PictureBox[]
                {DispB0, DispB1, DispB2, DispB3, DispB4, DispB5, DispB6, DispB7};

            DirCntl = new System.Windows.Forms.PictureBox[]
                {Dir0, Dir1, Dir2, Dir3, Dir4, Dir5, Dir6, Dir7};

            EdgeDisp = new System.Windows.Forms.PictureBox[]
                {Edge0, Edge1, Edge2, Edge3, Edge4, Edge5, Edge6, Edge7};

            OutBit = new System.Windows.Forms.CheckBox[]
                {OutB0, OutB1, OutB2, OutB3, OutB4, OutB5, OutB6, OutB7};
        }
        private void ControlEnable(Boolean en)
        {
            int Bit;

            DevOpenBtn.Enabled = !en;
            IDNUM.Enabled = !en;
            DevCloseBtn.Enabled = en;
            Timer1.Enabled = en;
            for (Bit = 0; Bit < 8; Bit++)
                OutBit[Bit].Enabled = en;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            int Bit;

            DevId = 0;
            ControlEnable(false);

            Timer1.Interval = 300;
            IDNUM.SelectedIndex = 0;
            for (Bit = 0; Bit < 8; Bit++)
            {
                StatDisp[Bit].Image = ImageList1.Images["Off"];
                DirCntl[Bit].Image = ImageList1.Images["UpEdge"];
                DirCntl[Bit].Tag = false;
                EdgeDisp[Bit].Image = ImageList1.Images["Off"];
            }
        }

        private void DevOpenBtn_Click(object sender, EventArgs e)
        {
            short retErr;

            DevId = (short)IDNUM.SelectedIndex;
            retErr = TUSBINS88.Tusbins88_Device_Open(DevId);
            if (retErr == 0)
            {
                ControlEnable(true);
                EdgeSet();
                OutputB();
            }
            else
                MessageBox.Show(TUSBINS88.GetOpenErrMessage(retErr));
        }

        private void DevClose()
        {
            TUSBINS88.Tusbins88_Device_Close(DevId);
            ControlEnable(false);
        }

        private void DevCloseBtn_Click(object sender, EventArgs e)
        {
            DevClose();
        }

        private void EdgeSet()
        {
            int Bit;
            byte dat;
            short retErr;

            dat = 0;
            for (Bit = 0; Bit < 8; Bit++)
                dat += (byte) (((Boolean)DirCntl[Bit].Tag) ? (1 << Bit) : 0);

            retErr = TUSBINS88.Tusbins88_EdgeSet(DevId, dat, (byte)IntervalTime.Value);
            if (retErr != 0)
            {
                MessageBox.Show(TUSBINS88.GetErrMessage(retErr));
                DevClose();
            }
        }

        private void Dir_MouseClick(object sender, MouseEventArgs e)
        {
            System.Windows.Forms.PictureBox image = (System.Windows.Forms.PictureBox)sender;

            if ((Boolean)image.Tag)
            {
                image.Tag = false;
                image.Image = ImageList1.Images["UpEdge"];
            }
            else
            {
                image.Tag = true;
                image.Image = ImageList1.Images["DownEdge"];
            }
            EdgeSet();
        }

        private void OutputB()
        {
            int Bit;
            byte Data;
            short retErr;

            Data = 0;
            for (Bit = 0; Bit < 8; Bit++)
            {
                Data += (byte)((OutBit[Bit].Checked) ? (1 << Bit) : 0);
            }

            retErr = TUSBINS88.Tusbins88_Write(DevId, Data);
            if (retErr != 0)
            {
                MessageBox.Show(TUSBINS88.GetErrMessage(retErr));
                DevClose();
            }
        }

        private void OutB_CheckedChanged(object sender, EventArgs e)
        {
            OutputB();
        }

        private void Timer1_Tick(object sender, EventArgs e)
        {
            byte dat;
            int Bit;
            short retErr;

            retErr = TUSBINS88.Tusbins88_Read(DevId, out dat);
            if (retErr != 0) //***DLL関数の実行
            {
                MessageBox.Show(TUSBINS88.GetErrMessage(retErr));
                DevClose();
                return;
            }
            else
            {
                for (Bit = 0; Bit < 8; Bit++)
                    StatDisp[Bit].Image = ((dat & (1 << Bit)) != 0) ? ImageList1.Images["On"] : ImageList1.Images["Off"];
            }

            retErr = TUSBINS88.Tusbins88_EdgeRead(DevId, out dat);
            if (retErr != 0) //***DLL関数の実行
            {
                MessageBox.Show(TUSBINS88.GetErrMessage(retErr));
                DevClose();
                return;
            }
            else
            {
                for (Bit = 0; Bit < 8; Bit++)
                    EdgeDisp[Bit].Image = ((dat & (1 << Bit)) != 0) ? ImageList1.Images["On"] : ImageList1.Images["Off"];
            }
        }

        private void IntervalTime_ValueChanged(object sender, EventArgs e)
        {
            EdgeSet();
        }
    }
}
